[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- PyICU
- parsedatetime: parsedatetime.py contains the `Calendar` class where the `parse()` method can be found.

- parsedatetime.parsedatetime: Parse human-readable date/time text.
- parsedatetime.parsedatetime_consts: parsedatetime constants and helper functions to determine regex values from Locale information if present.
- parsedatetime.tests: Unit tests for parsedatetime

- parsedatetime.tests.TestAustralianLocale: Test parsing of simple date and times using the Australian locale
- parsedatetime.tests.TestComplexDateTimes: Test parsing of complex date and times
- parsedatetime.tests.TestErrors: Test parsing of units
- parsedatetime.tests.TestInc: Test Calendar.Inc() routine
- parsedatetime.tests.TestMultiple: Test parsing of strings with multiple chunks
- parsedatetime.tests.TestPhrases: Test parsing of strings that are phrases
- parsedatetime.tests.TestRanges: Test parsing of simple date and times
- parsedatetime.tests.TestSimpleDateTimes: Test parsing of simple date and times
- parsedatetime.tests.TestSimpleOffsets: Test parsing of 'simple' offsets
- parsedatetime.tests.TestUnits: Test parsing of units